@@ -6,6 +6,7 @@ import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URISyntaxException;
 import java.net.URL;
+import java.net.URLConnection;
 import java.nio.file.Files;
 import java.nio.file.StandardCopyOption;
 import java.sql.Connection;
@@ -13,6 +14,7 @@ import java.sql.DatabaseMetaData;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.Properties;
+import java.util.UUID;
 import java.util.concurrent.Executor;
 import org.sqlite.SQLiteConfig.TransactionMode;
 import org.sqlite.core.CoreDatabaseMetaData;
@@ -303,7 +305,7 @@ public abstract class SQLiteConnection implements Connection {
         }
 
         String tempFolder = new File(System.getProperty("java.io.tmpdir")).getAbsolutePath();
-        String dbFileName = String.format("sqlite-jdbc-tmp-%d.db", resourceAddr.hashCode());
+        String dbFileName = String.format("sqlite-jdbc-tmp-%s.db", UUID.randomUUID());
         File dbFile = new File(tempFolder, dbFileName);
 
         if (dbFile.exists()) {
@@ -330,7 +332,10 @@ public abstract class SQLiteConnection implements Connection {
             //            }
         }
 
-        try (InputStream reader = resourceAddr.openStream()) {
+        URLConnection conn = resourceAddr.openConnection();
+        // Disable caches to avoid keeping unnecessary file references after the single-use copy
+        conn.setUseCaches(false);
+        try (InputStream reader = conn.getInputStream()) {
             Files.copy(reader, dbFile.toPath(), StandardCopyOption.REPLACE_EXISTING);
             return dbFile;
         }
@@ -564,4 +569,27 @@ public abstract class SQLiteConnection implements Connection {
     protected String transactionPrefix() {
         return this.connectionConfig.transactionPrefix();
     }
+
+    /**
+     * Returns a byte array representing the schema content. This method is intended for in-memory
+     * schemas. Serialized databases are limited to 2gb.
+     *
+     * @param schema The schema to serialize
+     * @return A byte[] holding the database content
+     */
+    public byte[] serialize(String schema) throws SQLException {
+        return db.serialize(schema);
+    }
+
+    /**
+     * Deserialize the schema using the given byte array. This method is intended for in-memory
+     * database. The call will replace the content of an existing schema. To make sure there is an
+     * existing schema, first execute ATTACH ':memory:' AS schema_name
+     *
+     * @param schema The schema to serialize
+     * @param buff The buffer to deserialize
+     */
+    public void deserialize(String schema, byte[] buff) throws SQLException {
+        db.deserialize(schema, buff);
+    }
 }
