@@ -9,8 +9,7 @@
 // --------------------------------------
 package org.sqlite;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 import java.sql.SQLException;
 import org.junit.jupiter.api.Test;
@@ -22,52 +21,52 @@ public class ExtendedCommandTest {
 
     public static BackupCommand parseBackupCommand(String sql) throws SQLException {
         SQLExtension e = ExtendedCommand.parse(sql);
-        assertTrue(e instanceof BackupCommand);
+        assertThat(e instanceof BackupCommand).isTrue();
         return (BackupCommand) e;
     }
 
     public static RestoreCommand parseRestoreCommand(String sql) throws SQLException {
         SQLExtension e = ExtendedCommand.parse(sql);
-        assertTrue(e instanceof RestoreCommand);
+        assertThat(e instanceof RestoreCommand).isTrue();
         return (RestoreCommand) e;
     }
 
     @Test
     public void parseBackupCmd() throws SQLException {
         BackupCommand b = parseBackupCommand("backup mydb to somewhere/backupfolder/mydb.sqlite");
-        assertEquals("mydb", b.srcDB);
-        assertEquals("somewhere/backupfolder/mydb.sqlite", b.destFile);
+        assertThat(b.srcDB).isEqualTo("mydb");
+        assertThat(b.destFile).isEqualTo("somewhere/backupfolder/mydb.sqlite");
 
         b = parseBackupCommand("backup main to \"tmp folder with space\"");
-        assertEquals("main", b.srcDB);
-        assertEquals("tmp folder with space", b.destFile);
+        assertThat(b.srcDB).isEqualTo("main");
+        assertThat(b.destFile).isEqualTo("tmp folder with space");
 
         b = parseBackupCommand("backup main to 'tmp folder with space'");
-        assertEquals("main", b.srcDB);
-        assertEquals("tmp folder with space", b.destFile);
+        assertThat(b.srcDB).isEqualTo("main");
+        assertThat(b.destFile).isEqualTo("tmp folder with space");
 
         b = parseBackupCommand("backup to target/sample.db");
-        assertEquals("main", b.srcDB);
-        assertEquals("target/sample.db", b.destFile);
+        assertThat(b.srcDB).isEqualTo("main");
+        assertThat(b.destFile).isEqualTo("target/sample.db");
     }
 
     @Test
     public void parseRestoreCmd() throws SQLException {
         RestoreCommand b =
                 parseRestoreCommand("restore mydb from somewhere/backupfolder/mydb.sqlite");
-        assertEquals("mydb", b.targetDB);
-        assertEquals("somewhere/backupfolder/mydb.sqlite", b.srcFile);
+        assertThat(b.targetDB).isEqualTo("mydb");
+        assertThat(b.srcFile).isEqualTo("somewhere/backupfolder/mydb.sqlite");
 
         b = parseRestoreCommand("restore main from \"tmp folder with space\"");
-        assertEquals("main", b.targetDB);
-        assertEquals("tmp folder with space", b.srcFile);
+        assertThat(b.targetDB).isEqualTo("main");
+        assertThat(b.srcFile).isEqualTo("tmp folder with space");
 
         b = parseRestoreCommand("restore main from 'tmp folder with space'");
-        assertEquals("main", b.targetDB);
-        assertEquals("tmp folder with space", b.srcFile);
+        assertThat(b.targetDB).isEqualTo("main");
+        assertThat(b.srcFile).isEqualTo("tmp folder with space");
 
         b = parseRestoreCommand("restore from target/sample.db");
-        assertEquals("main", b.targetDB);
-        assertEquals("target/sample.db", b.srcFile);
+        assertThat(b.targetDB).isEqualTo("main");
+        assertThat(b.srcFile).isEqualTo("target/sample.db");
     }
 }
